@@ -1,41 +1,35 @@
 // Copyright 2022-2023 Sebastian Ramacher
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-use std::collections::HashMap;
-use std::io::{BufRead, BufReader, Write};
-use std::path::Path;
-use std::{collections::HashSet, fs::File};
+use std::{
+    collections::{HashMap, HashSet},
+    fs::File,
+    io::{BufRead, BufReader, Write},
+    path::Path,
+};
 
-use anyhow::{anyhow, Context, Result};
+use anyhow::{Context, Result, anyhow};
 use assorted_debian_utils::{
     architectures::Architecture,
-    archive::{Codename, Suite},
+    archive::{Codename, SuiteOrCodename},
     buildinfo::{self, Buildinfo},
+    package::PackageName,
     rfc822_like,
     version::PackageVersion,
     wb::{BinNMU, SourceSpecifier, WBCommand, WBCommandBuilder},
 };
 use async_trait::async_trait;
 use indicatif::{ProgressBar, ProgressIterator};
-use serde::Deserialize;
 
 use crate::{
-    cli::{BaseOptions, BinNMUBuildinfoOptions},
-    config::{default_progress_style, default_progress_template, Cache, CacheEntries},
-    source_packages::SourcePackages,
-    udd_bugs::{load_bugs_from_reader, UDDBugs},
-    utils::execute_wb_commands,
     AsyncCommand, Downloads,
+    cli::{BaseOptions, BinNMUBuildinfoOptions},
+    config::{Cache, CacheEntries, default_progress_style, default_progress_template},
+    source_packages::{BinaryPackage, SourcePackages},
+    udd_bugs::{UDDBugs, load_bugs_from_reader},
+    utils::execute_wb_commands,
 };
 
-#[derive(Deserialize)]
-#[serde(rename_all = "PascalCase")]
-struct BinaryPackage {
-    source: Option<String>,
-    package: String,
-    version: PackageVersion,
-}
-
 pub(crate) struct BinNMUBuildinfo<'a> {
     cache: &'a Cache,
     base_options: &'a BaseOptions,
@@ -55,7 +49,7 @@ impl<'a> BinNMUBuildinfo<'a> {
         }
     }
 
-    fn parse_packages(path: impl AsRef<Path>) -> Result<HashSet<(String, PackageVersion)>> {
+    fn parse_packages(path: impl AsRef<Path>) -> Result<HashSet<(PackageName, PackageVersion)>> {
         // read Package file
         let binary_packages: Vec<BinaryPackage> = rfc822_like::from_file(path.as_ref())
             .with_context(|| {
@@ -68,17 +62,7 @@ impl<'a> BinNMUBuildinfo<'a> {
         Ok(binary_packages
             .into_iter()
             .progress_with(pb)
-            .map(|binary_package| {
-                if let Some(source_package) = &binary_package.source {
-                    (
-                        source_package.split_whitespace().next().unwrap().into(),
-                        binary_package.version,
-                    )
-                } else {
-                    // no Source set, so Source == Package
-                    (binary_package.package, binary_package.version)
-                }
-            })
+            .map(|binary_package| binary_package.name_and_version())
             .collect())
     }
 
@@ -86,12 +70,9 @@ impl<'a> BinNMUBuildinfo<'a> {
         &self,
         buildinfo: Buildinfo,
         source_packages: &SourcePackages,
-        source_versions: &HashMap<String, PackageVersion>,
+        source_versions: &HashMap<PackageName, PackageVersion>,
         ftbfs_bugs: &UDDBugs,
     ) -> Result<WBCommand> {
-        let mut source_split = buildinfo.source.split_whitespace();
-        let source_package = source_split.next().unwrap();
-
         let architectures: Vec<Architecture> = buildinfo
             .architecture
             .into_iter()
@@ -101,7 +82,7 @@ impl<'a> BinNMUBuildinfo<'a> {
             return Err(anyhow!("no binNMU-able architecture"));
         }
 
-        match source_versions.get(source_package) {
+        match source_versions.get(&buildinfo.source) {
             Some(version) => {
                 if version > &buildinfo.version {
                     return Err(anyhow!("newer version in archive"));
@@ -110,16 +91,19 @@ impl<'a> BinNMUBuildinfo<'a> {
             None => return Err(anyhow!("removed from the archive")),
         }
 
-        if ftbfs_bugs.bugs_for_source(source_package).is_some() {
+        if ftbfs_bugs
+            .bugs_for_source(buildinfo.source.as_ref())
+            .is_some()
+        {
             return Err(anyhow!("skipping due to FTBFS bugs"));
         }
 
-        let mut source = SourceSpecifier::new(source_package);
+        let mut source = SourceSpecifier::new(&buildinfo.source);
         let version = buildinfo.version.without_binnmu_version();
         source
             .with_version(&version)
             .with_suite(self.options.binnmu_options.suite);
-        if !source_packages.is_ma_same(source_package) {
+        if !source_packages.is_ma_same(&buildinfo.source) {
             // binNMU only on the architecture if no MA: same binary packages
             source.with_archive_architectures(&architectures);
         }
@@ -141,7 +125,7 @@ impl<'a> BinNMUBuildinfo<'a> {
         &self,
         path: impl AsRef<Path>,
         source_packages: &SourcePackages,
-        source_versions: &HashMap<String, PackageVersion>,
+        source_versions: &HashMap<PackageName, PackageVersion>,
         ftbfs_bugs: &UDDBugs,
     ) -> Result<HashSet<WBCommand>> {
         let mut ret = HashSet::new();
@@ -184,8 +168,11 @@ impl<'a> BinNMUBuildinfo<'a> {
 impl AsyncCommand for BinNMUBuildinfo<'_> {
     async fn run(&self) -> Result<()> {
         // store latest version of all source packages
-        let mut source_versions: HashMap<String, PackageVersion> = HashMap::new();
-        for path in self.cache.get_package_paths(Suite::Unstable, true)? {
+        let mut source_versions = HashMap::new();
+        for path in self
+            .cache
+            .get_package_paths(SuiteOrCodename::UNSTABLE, true)?
+        {
             for (source, version) in Self::parse_packages(path)? {
                 match source_versions.get_mut(&source) {
                     Some(old_ver) => {
@@ -199,8 +186,11 @@ impl AsyncCommand for BinNMUBuildinfo<'_> {
                 }
             }
         }
-        let source_packages =
-            SourcePackages::new(&self.cache.get_package_paths(Suite::Unstable, false)?)?;
+        let source_packages = SourcePackages::new(
+            &self
+                .cache
+                .get_package_paths(SuiteOrCodename::UNSTABLE, false)?,
+        )?;
 
         let ftbfs_bugs = if self.base_options.force_processing {
             UDDBugs::new(vec![])
