@@ -6,7 +6,7 @@ use std::{cmp::min, collections::HashSet};
 use anyhow::Result;
 use assorted_debian_utils::{
     architectures::Architecture,
-    archive::{Component, Suite, SuiteOrCodename},
+    archive::{Component, SuiteOrCodename},
     excuses::{self, ExcusesItem, PolicyInfo, Verdict},
     wb::{BinNMU, SourceSpecifier, WBArchitecture, WBCommand, WBCommandBuilder},
 };
@@ -16,11 +16,11 @@ use log::{debug, error, info, trace, warn};
 use serde::{Deserialize, Serialize};
 
 use crate::{
+    AsyncCommand, Downloads,
     cli::{BaseOptions, ProcessExcusesOptions},
-    config::{self, default_progress_template, CacheEntries},
+    config::{self, CacheEntries, default_progress_template},
     source_packages::SourcePackages,
     utils::execute_wb_commands,
-    AsyncCommand, Downloads,
 };
 
 const SCHEDULED_BINNMUS: &str = "scheduled-binnmus.yaml";
@@ -85,8 +85,7 @@ impl<'a> ProcessExcuses<'a> {
                 // too young
                 trace!(
                     "no binnmu possible: too young: {} days (required: {} days)",
-                    a.current_age,
-                    a.age_requirement
+                    a.current_age, a.age_requirement
                 );
                 return false;
             }
@@ -174,7 +173,7 @@ impl<'a> ProcessExcuses<'a> {
 
     fn build_unblock(item: &ExcusesItem) -> Option<String> {
         let mut unblock = String::from("unblock ");
-        unblock.push_str(&item.source);
+        unblock.push_str(item.source.as_ref());
         // append _tpu if item is from _tpu
         if item.is_from_tpu() {
             unblock.push_str("_tpu");
@@ -282,8 +281,11 @@ impl<'a> ProcessExcuses<'a> {
 #[async_trait]
 impl AsyncCommand for ProcessExcuses<'_> {
     async fn run(&self) -> Result<()> {
-        let source_packages =
-            SourcePackages::new(&self.cache.get_package_paths(Suite::Unstable, false)?)?;
+        let source_packages = SourcePackages::new(
+            &self
+                .cache
+                .get_package_paths(SuiteOrCodename::UNSTABLE, false)?,
+        )?;
         // parse excuses
         let excuses = excuses::from_reader(self.cache.get_cache_bufreader("excuses.yaml")?)?;
 
@@ -300,7 +302,7 @@ impl AsyncCommand for ProcessExcuses<'_> {
             .progress_with(pb)
             .filter_map(|item| self.build_action(item, &source_packages))
             .filter(|action| match action {
-                Action::BinNMU(ref command) => {
+                Action::BinNMU(command) => {
                     if scheduled_binnmus.contains(command) {
                         info!("{}: skipping, already scheduled", command);
                         false
